AcceptedTerms class abstract

Implemented types

Constructors

AcceptedTerms({int? id, required Terms termsType, required String termsVersion, DateTime? createdAt, required String identifier})
factory
AcceptedTerms.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

createdAt DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
The database id, set if the object has been inserted into the database or if it has been fetched from the database. Otherwise, the id will be null.
getter/setter pair
identifier String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsType Terms
getter/setter pair
termsVersion String
getter/setter pair

Methods

copyWith({int? id, Terms? termsType, String? termsVersion, DateTime? createdAt, String? identifier}) AcceptedTerms
Returns a shallow copy of this AcceptedTerms with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited