AuthTokenInfo class abstract

Implemented types

Constructors

AuthTokenInfo({required String tokenId, required String issuer, required String method, required DateTime createdAt, DateTime? expiresAt, Duration? expireAfterUnusedFor, DateTime? lastUsedAt})
factory
AuthTokenInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

createdAt DateTime
getter/setter pair
expireAfterUnusedFor Duration?
getter/setter pair
expiresAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issuer String
getter/setter pair
lastUsedAt DateTime?
getter/setter pair
method String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenId String
getter/setter pair

Methods

copyWith({String? tokenId, String? issuer, String? method, DateTime? createdAt, DateTime? expiresAt, Duration? expireAfterUnusedFor, DateTime? lastUsedAt}) AuthTokenInfo
Returns a shallow copy of this AuthTokenInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited