BillingInfo class abstract

Implemented types

Constructors

BillingInfo({UuidValue? id, DateTime? createdAt, DateTime? updatedAt, required UuidValue ownerId, Owner? owner, String? companyName, required String addressLine1, String? addressLine2, required String postalCode, required String city, String? state, required String country, String? vatNumber, String? vatType, BillingCustomerType? customerType})
factory
BillingInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

addressLine1 String
getter/setter pair
addressLine2 String?
getter/setter pair
city String
getter/setter pair
companyName String?
getter/setter pair
country String
getter/setter pair
createdAt DateTime?
getter/setter pair
customerType BillingCustomerType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id UuidValue
The id of the object.
getter/setter pair
owner Owner?
getter/setter pair
ownerId UuidValue
getter/setter pair
postalCode String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
getter/setter pair
updatedAt DateTime?
getter/setter pair
vatNumber String?
getter/setter pair
vatType String?
getter/setter pair

Methods

copyWith({UuidValue? id, DateTime? createdAt, DateTime? updatedAt, UuidValue? ownerId, Owner? owner, String? companyName, String? addressLine1, String? addressLine2, String? postalCode, String? city, String? state, String? country, String? vatNumber, String? vatType, BillingCustomerType? customerType}) BillingInfo
Returns a shallow copy of this BillingInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited