CapsuleDeploymentStatus class abstract

The runtime status of a capsule's deployment.

Implemented types

Constructors

CapsuleDeploymentStatus({required String name, required CapsuleState state, int? desiredReplicas, int? readyReplicas, UuidValue? uploadId, UuidValue? buildId, CapsuleRevision? incoming})
factory
CapsuleDeploymentStatus.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

buildId UuidValue?
The build the deployment is currently serving. Absent when unknown.
getter/setter pair
desiredReplicas int?
The number of replicas the deployment wants. Present whenever the workload exists.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
incoming CapsuleRevision?
The revision currently being rolled out toward this deployment. Present only while a rollout is in flight.
getter/setter pair
name String
The name of the deployment.
getter/setter pair
readyReplicas int?
The number of replicas ready to serve. Present whenever the workload exists.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CapsuleState
The runtime state of the deployment.
getter/setter pair
uploadId UuidValue?
The upload the deployment is currently serving. Absent when unknown.
getter/setter pair

Methods

copyWith({String? name, CapsuleState? state, int? desiredReplicas, int? readyReplicas, UuidValue? uploadId, UuidValue? buildId, CapsuleRevision? incoming}) CapsuleDeploymentStatus
Returns a shallow copy of this CapsuleDeploymentStatus with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited