ComputeInfo class abstract

Implemented types

Constructors

ComputeInfo({required String cloudCapsuleId, required ComputeSizeOption size, required int minInstances, required int maxInstances, required int memoryMb})
factory
ComputeInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

cloudCapsuleId String
The globally unique identifier of the capsule.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxInstances int
The maximum number of instances the capsule can scale to.
getter/setter pair
memoryMb int
The memory of the capsule compute in megabytes.
getter/setter pair
minInstances int
The minimum number of instances the capsule can scale to.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComputeSizeOption
The size of the capsule compute. small, medium, large, or unknown. A value of unknown means the size could not be determined.
getter/setter pair

Methods

copyWith({String? cloudCapsuleId, ComputeSizeOption? size, int? minInstances, int? maxInstances, int? memoryMb}) ComputeInfo
Returns a shallow copy of this ComputeInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited