CustomDomainName class abstract
- Implemented types
Constructors
- CustomDomainName({int? id, required String name, required DomainNameStatus status, required DomainNameTarget target, DateTime? createdAt, required int capsuleId, required String dnsRecordVerificationValue, required DnsRecordType dnsRecordType})
-
factory
-
CustomDomainName.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- capsuleId ↔ int
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- dnsRecordType ↔ DnsRecordType
-
getter/setter pair
- dnsRecordVerificationValue ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ DomainNameStatus
-
getter/setter pair
- target ↔ DomainNameTarget
-
getter/setter pair
Methods
-
copyWith(
{int? id, String? name, DomainNameStatus? status, DomainNameTarget? target, DateTime? createdAt, int? capsuleId, String? dnsRecordVerificationValue, DnsRecordType? dnsRecordType}) → CustomDomainName - Returns a shallow copy of this CustomDomainName with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited