CustomDomainNameList class abstract

Implemented types

Constructors

CustomDomainNameList({required List<CustomDomainName> customDomainNames, required Map<DomainNameTarget, String> defaultDomainsByTarget})
factory
CustomDomainNameList.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

customDomainNames List<CustomDomainName>
getter/setter pair
defaultDomainsByTarget Map<DomainNameTarget, String>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<CustomDomainName>? customDomainNames, Map<DomainNameTarget, String>? defaultDomainsByTarget}) CustomDomainNameList
Returns a shallow copy of this CustomDomainNameList with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited