procurePlan method
Procures a plan for a user.
If planProductVersion is not provided, the latest version is used.
If trialPeriodOverride is provided, it will override the trial period (number of days)
in billing. The owner's trial end is synced from the new subscription afterward.
If overrideChecks is true, the product availability checks are overridden.
Returns the subscription ID of the created subscription.
Throws a NotFoundException if the user or product is not found. Throws a InvalidValueException if the user has no owner (not fully registered).
Implementation
_i2.Future<_i1.UuidValue> procurePlan({
required String userEmail,
required String planProductName,
int? planProductVersion,
int? trialPeriodOverride,
bool? overrideChecks,
}) => caller
.callServerEndpoint<_i1.UuidValue>('adminProcurement', 'procurePlan', {
'userEmail': userEmail,
'planProductName': planProductName,
'planProductVersion': planProductVersion,
'trialPeriodOverride': trialPeriodOverride,
'overrideChecks': overrideChecks,
});