EndpointAdminProjects class Endpoint
Endpoint for global administrator projects access.
- Inheritance
-
- Object
- EndpointRef
- EndpointAdminProjects
- Implementers
Constructors
- EndpointAdminProjects(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
SerializableModel> -
Stream of messages sent from an endpoint that supports streaming.
no setterinherited
Methods
-
getDeployAttempts(
{required String cloudCapsuleId, int? limit}) → Future< List< DeployAttempt> > -
Gets deploy attempts of the specified capsule.
Gets the recent-most attempts, up till
limitif specified. -
listProjects(
{bool? includeArchived}) → Future< List< Project> > - Fetches the list of all projects. The result includes the owners for each project.
-
listProjectsInfo(
{bool? includeArchived, bool? includeLatestDeployAttemptTime}) → Future< List< ProjectInfo> > - Fetches the list of all projects. The result includes the owners for each project and the latest deploy attempt time (or null if undeployed).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redeployCapsule(
String cloudProjectId) → Future< void> - Redeploys a capsule using its current image. Triggers a deploymentUpdated event to redeploy the infrastructure.
-
resetStream(
) → void -
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(
SerializableModel message) → Future< void> -
Sends a message to the endpoint's stream.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited