EndpointAdminUpdatePlan class Endpoint

Inheritance

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listOrbPlans() Future<List<String>>
Lists all handled Orb plans by external plan id.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateOrbPlan({required String externalPlanId}) Future<Map<String, String>>
Pushes the current configuration for a plan to Orb.

Operators

operator ==(Object other) bool
The equality operator.
inherited