EndpointAuth class Endpoint

Endpoint for authentication.

Inheritance
Implementers

Constructors

EndpointAuth(EndpointCaller caller)

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

finishEmailAccountRegistration({required String finishRegistrationToken, required String password}) Future<AuthSuccess>
Completes a new account registration, creating a new auth user with a profile, and creating a new authenticated session for the user.
finishPasswordReset({required UuidValue passwordResetRequestId, required String verificationCode, required String newPassword}) Future<AuthSuccess>
Completes a password reset request by setting a new password.
login({required String email, required String password}) Future<AuthSuccess>
Logs in the user and returns a new session.
logoutDevice() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRequiredTerms() Future<List<RequiredTerms>>
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
startEmailAccountRegistration({required String email, required List<AcceptedTermsDTO> acceptedTerms}) Future<void>
Starts the registration for a new user account with an email-based login.
startPasswordReset({required String email}) Future<void>
Requests a password reset for email.
toString() String
A string representation of this object.
inherited
verifyRegistrationCode({required UuidValue accountRequestId, required String verificationCode}) Future<String>
Verifies a registration code and returns the finish registration token.

Operators

operator ==(Object other) bool
The equality operator.
inherited