finishPasswordReset method
Completes a password reset request by setting a new password.
If the reset was successful, a new session key is returned.
If the reset failed, one of the following exceptions is thrown:
EmailAccountPasswordPolicyViolationExceptionEmailAccountPasswordResetRequestExpiredExceptionEmailAccountPasswordResetRequestNotFoundExceptionEmailAccountPasswordResetRequestUnauthorizedExceptionEmailAccountPasswordResetTooManyAttemptsException
Destroys all the user's current sessions, and creates a new authenticated session for the user.
Implementation
_i2.Future<_i10.AuthSuccess> finishPasswordReset({
required _i1.UuidValue passwordResetRequestId,
required String verificationCode,
required String newPassword,
}) => caller
.callServerEndpoint<_i10.AuthSuccess>('auth', 'finishPasswordReset', {
'passwordResetRequestId': passwordResetRequestId,
'verificationCode': verificationCode,
'newPassword': newPassword,
});