login method

Future<AuthSuccess> login({
  1. required String email,
  2. required String password,
})

Logs in the user and returns a new session.

In case an expected error occurs, this throws a EmailAccountLoginException.

Implementation

_i2.Future<_i10.AuthSuccess> login({
  required String email,
  required String password,
}) => caller.callServerEndpoint<_i10.AuthSuccess>('auth', 'login', {
  'email': email,
  'password': password,
});