startEmailAccountRegistration method

Future<void> startEmailAccountRegistration({
  1. required String email,
  2. required List<AcceptedTermsDTO> acceptedTerms,
})

Starts the registration for a new user account with an email-based login.

Upon successful completion of this method, an email will have been sent to email with a verification link, which the user must open to complete the registration.

Throws UserAccountRegistrationDeniedException if the user is not authorized to start an account registration, or has not accepted the required terms of service.

Implementation

_i2.Future<void> startEmailAccountRegistration({
  required String email,
  required List<_i9.AcceptedTermsDTO> acceptedTerms,
}) => caller.callServerEndpoint<void>(
  'auth',
  'startEmailAccountRegistration',
  {'email': email, 'acceptedTerms': acceptedTerms},
);