logoutDevice method
Log out the current user from a login session.
If no authTokenId is provided, it will log out the current one.
The user's other login sessions and API tokens will not be affected.
Returns true if it was the current session that was logged out, false if it was a different session.
Implementation
_i2.Future<bool> logoutDevice({String? authTokenId}) =>
caller.callServerEndpoint<bool>('authWithAuth', 'logoutDevice', {
'authTokenId': authTokenId,
});