EndpointBilling class Endpoint

Inheritance
Implementers

Constructors

EndpointBilling(EndpointCaller caller)

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

createSetupIntent() Future<PaymentSetupIntent>
Creates a setup intent for collecting payment methods.
isPaymentMethodRequired() Future<bool>
Checks if a payment method is required for the authenticated user.
listPaymentMethods() Future<List<PaymentMethod>>
Lists all payment methods for the authenticated user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ownerIsInGoodStanding() Future<bool>
Checks if the owner is in good standing.
readOwner() Future<Owner>
Reads the owner information.
removePaymentMethod({required String paymentMethodId}) Future<void>
Removes a payment method for the authenticated user.
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
setDefaultPaymentMethod({required String paymentMethodId}) Future<void>
Sets the default payment method for the authenticated user.
setOwnerCustomerType({required BillingCustomerType customerType}) Future<Owner>
Sets the owner's customer type (private or business) as a stop-gap until B2C/B2B migration is supported.
toString() String
A string representation of this object.
inherited
updateOwnerBilling({required List<String> billingEmails, required BillingInfo billingInfo}) Future<Owner>
Updates the owner's billing information.

Operators

operator ==(Object other) bool
The equality operator.
inherited