isPaymentMethodRequired method

Future<bool> isPaymentMethodRequired()

Checks if a payment method is required for the authenticated user.

This endpoint returns true if the user has active (non-archived) projects, meaning they cannot delete their last payment method. Returns false otherwise.

Returns true if a payment method is required, false otherwise.

Implementation

_i2.Future<bool> isPaymentMethodRequired() =>
    caller.callServerEndpoint<bool>('billing', 'isPaymentMethodRequired', {});