EndpointCompute class Endpoint
Endpoint for reading and updating capsule compute configuration.
- Inheritance
-
- Object
- EndpointRef
- EndpointCompute
Constructors
- EndpointCompute(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readCompute(
{required String cloudCapsuleId}) → Future< ComputeInfo> - Reads the compute for a capsule.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCompute(
{required String cloudCapsuleId, required ComputeSizeOption size, required int minInstances, required int maxInstances}) → Future< ComputeInfo> - Updates the compute configuration for a capsule.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited