updateDatabaseSize method
Future<DatabaseResource>
updateDatabaseSize({
- required String cloudCapsuleId,
- required DatabaseSizeOption size,
- double? minCu,
- double? maxCu,
Updates the size and the autoscaling CU limits for a capsule's database, changing the procured database product if necessary. The size and limits are validated against the constraints of the capsule's product.
minCu and maxCu must be provided together or both omitted.
Throws ProcurementDeniedException if the size is not available for the capsule. Throws InvalidValueException if the size, minCu, and maxCu combination is invalid. Throws NotFoundException if no database is found for the capsule.
Implementation
_i2.Future<_i26.DatabaseResource> updateDatabaseSize({
required String cloudCapsuleId,
required _i27.DatabaseSizeOption size,
double? minCu,
double? maxCu,
}) => caller.callServerEndpoint<_i26.DatabaseResource>(
'database',
'updateDatabaseSize',
{
'cloudCapsuleId': cloudCapsuleId,
'size': size,
'minCu': minCu,
'maxCu': maxCu,
},
);