startRegistration method

  1. @override
Future<UuidValue> startRegistration({
  1. required String email,
  2. String? name,
  3. List<AcceptedTermsDTO>? acceptedTerms,
})

Starts the registration for a new user account.

Accepts an optional name and required acceptedTerms in addition to email. Validates terms acceptance and stores the user's name before delegating to the email IDP.

Throws UserAccountRegistrationDeniedException if the user has not accepted the required terms of service.

Always returns a account request ID, which can be used to complete the registration. If the email is already registered, the returned ID will not be valid.

Implementation

@override
_i2.Future<_i1.UuidValue> startRegistration({
  required String email,
  String? name,
  List<_i9.AcceptedTermsDTO>? acceptedTerms,
}) => caller.callServerEndpoint<_i1.UuidValue>(
  'emailIdp',
  'startRegistration',
  {'email': email, 'name': name, 'acceptedTerms': acceptedTerms},
);