verifyRegistrationCode method

  1. @override
Future<String> verifyRegistrationCode({
  1. required UuidValue accountRequestId,
  2. required String verificationCode,
})

Verifies an account request code and returns a token that can be used to complete the account creation.

Throws an EmailAccountRequestException in case of errors, with reason:

  • EmailAccountRequestExceptionReason.expired if the account request has already expired.
  • EmailAccountRequestExceptionReason.policyViolation if the password does not comply with the password policy.
  • EmailAccountRequestExceptionReason.invalid if no request exists for the given accountRequestId or verificationCode is invalid.

Implementation

@override
_i2.Future<String> verifyRegistrationCode({
  required _i1.UuidValue accountRequestId,
  required String verificationCode,
}) =>
    caller.callServerEndpoint<String>('emailIdp', 'verifyRegistrationCode', {
      'accountRequestId': accountRequestId,
      'verificationCode': verificationCode,
    });