Methods
-
hasAccount()
→ Future<bool>
-
Returns the
method value for each connected Idp subclass if the
current session is authenticated and if the user has an account connected
to the Idp.
-
login({required String code, required String codeVerifier, required String redirectUri})
→ Future<AuthSuccess>
-
Validates a GitHub authorization code and either logs in the associated
user or creates a new user account if the GitHub account ID is not yet
known.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resetStream()
→ void
-
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(SerializableModel message)
→ Future<void>
-
Sends a message to the endpoint's stream.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited