Methods
-
hasAccount()
→ Future<bool>
-
Returns the
method value for each connected Idp subclass if the
current session is authenticated and if the user has an account connected
to the Idp.
-
login({required String idToken, required String? accessToken})
→ Future<AuthSuccess>
-
Validates a Google ID token and either logs in the associated user or
creates a new user account if the Google account ID is not yet known.
-
loginWithCode({required String code, required String codeVerifier, required String redirectUri})
→ Future<AuthSuccess>
-
Validates a Google authorization code from the web OAuth2 PKCE flow and
either logs in the associated user or creates a new account.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited