createProject method

Future<Project> createProject({
  1. required String cloudProjectId,
  2. UuidValue? underSubscriptionId,
  3. String? projectProductName,
})

Creates a new project with basic setup.

Currently also creates its capsule.

cloudProjectId is the id of the new project, it must be valid and globally unique.

underSubscriptionId optionally specifies a subscription to procure the project under, or the user's first found subscription will be used. In future this parameter will be mandatory.

projectProductName optionally specify the project product name to use, defaults to the first available bundled product for the subscription plan.

Throws ProcurementDeniedException if the project procurement fails or the subscription is invalid. Throws InvalidValueException if the project name is invalid. Throws DuplicateEntryException if the project id already exists. Throws NoSubscriptionException if no subscription was provided and the user has no subscription.

Implementation

_i2.Future<_i3.Project> createProject({
  required String cloudProjectId,
  _i1.UuidValue? underSubscriptionId,
  String? projectProductName,
}) => caller.callServerEndpoint<_i3.Project>('projects', 'createProject', {
  'cloudProjectId': cloudProjectId,
  'underSubscriptionId': underSubscriptionId,
  'projectProductName': projectProductName,
});