inviteUser method
Invites a user to a project by assigning the specified project roles. If the user does not exist, a user invitation email is sent.
Throws NotFoundException if the project or any of the roles do not exist.
Implementation
_i2.Future<void> inviteUser({
required String cloudProjectId,
required String email,
required List<String> assignRoleNames,
}) => caller.callServerEndpoint<void>('projects', 'inviteUser', {
'cloudProjectId': cloudProjectId,
'email': email,
'assignRoleNames': assignRoleNames,
});