upsert method

Future<void> upsert({
  1. required Map<String, String> secrets,
  2. required String cloudCapsuleId,
})

Upserts custom (user-defined) secrets for a cloud capsule.

Creates new secrets or updates existing ones. Unlike create, this method allows updating existing secret keys without throwing an exception.

Secret value changes are applied at the next successful deployment.

Throws NotFoundException if the capsule is not found. Throws InvalidValueException if secret names are invalid.

Implementation

_i2.Future<void> upsert({
  required Map<String, String> secrets,
  required String cloudCapsuleId,
}) => caller.callServerEndpoint<void>('secrets', 'upsert', {
  'secrets': secrets,
  'cloudCapsuleId': cloudCapsuleId,
});