EndpointStatus class Endpoint
Endpoint for accessing capsule deployment status.
- Inheritance
-
- Object
- EndpointRef
- EndpointStatus
Constructors
- EndpointStatus(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
SerializableModel> -
Stream of messages sent from an endpoint that supports streaming.
no setterinherited
Methods
-
getCapsuleRuntimeStatus(
{required String cloudCapsuleId}) → Future< CapsuleRuntimeStatus> - Gets the live runtime status of the specified capsule, enriched with summaries of the deploy attempts behind the serving and incoming revisions. An unhealthy capsule is still a successful result — the status is data.
-
getCapsuleStatus(
{required String cloudCapsuleId}) → Future< CapsuleStatus> - Gets the live runtime status of the specified capsule. An unhealthy capsule is still a successful result — the status is data.
-
getDeployAttemptId(
{required String cloudCapsuleId, required int attemptNumber}) → Future< UuidValue> - Gets the deploy attempt id for the specified attempt number of a capsule. This number enumerate the capsule's deploy attempts as latest first, starting from 0.
-
getDeployAttempts(
{required String cloudCapsuleId, int? limit}) → Future< List< DeployAttempt> > -
Gets deploy attempts of the specified capsule.
Gets the recent-most attempts, up till
limitif specified. -
getDeployAttemptStatus(
{required String cloudCapsuleId, required UuidValue attemptId}) → Future< List< DeployAttemptStage> > - Gets the specified deploy attempt status of the a capsule.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetStream(
) → void -
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(
SerializableModel message) → Future< void> -
Sends a message to the endpoint's stream.
inherited
-
tailCapsuleStatus(
{required String cloudCapsuleId}) → Stream< CapsuleStatus> - Tails the live runtime status of the specified capsule. Emits the current status immediately, then an update whenever it changes. Continues until the client unsubscribes.
-
tailDeployAttemptStatus(
{required String cloudCapsuleId, required UuidValue attemptId}) → Stream< DeployAttemptStage> - Tails the status updates for a deploy attempt. Continues until the client unsubscribes or the status if final.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited