tailCapsuleStatus method

Stream<CapsuleStatus> tailCapsuleStatus({
  1. required String cloudCapsuleId,
})

Tails the live runtime status of the specified capsule. Emits the current status immediately, then an update whenever it changes. Continues until the client unsubscribes.

Implementation

_i2.Stream<_i40.CapsuleStatus> tailCapsuleStatus({
  required String cloudCapsuleId,
}) =>
    caller.callStreamingServerEndpoint<
      _i2.Stream<_i40.CapsuleStatus>,
      _i40.CapsuleStatus
    >('status', 'tailCapsuleStatus', {'cloudCapsuleId': cloudCapsuleId}, {});