EndpointUsers class Endpoint

Endpoint for managing users.

Inheritance

Constructors

EndpointUsers(EndpointCaller caller)

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listUsersInProject({required String cloudProjectId}) Future<List<User>>
Reads all users that have a role in the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readUser() Future<User>
Reads the current user's information.
toString() String
A string representation of this object.
inherited
updateUserName(String name) Future<User>
Updates current user's name.

Operators

operator ==(Object other) bool
The equality operator.
inherited