copyWith abstract method
Returns a shallow copy of this InsightsConnectionDetail with some or all fields replaced by the given arguments.
Implementation
@_i1.useResult
InsightsConnectionDetail copyWith({Uri? url, String? serviceSecret});
Returns a shallow copy of this InsightsConnectionDetail with some or all fields replaced by the given arguments.
@_i1.useResult
InsightsConnectionDetail copyWith({Uri? url, String? serviceSecret});