LogRecord class abstract

Represents a log record (entry).

Implemented types

Constructors

LogRecord({required String cloudProjectId, required String cloudCapsuleId, required String recordId, required DateTime timestamp, String? severity, required String content})
factory
LogRecord.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

cloudCapsuleId String
The ID of the capsule this log record is from.
getter/setter pair
cloudProjectId String
The ID of the project this log record is from.
getter/setter pair
content String
The log message content. May be a string or a string-encoded JSON object.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recordId String
The ID of this log record.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String?
The severity level of the log record.
getter/setter pair
timestamp DateTime
The timestamp of the log record.
getter/setter pair

Methods

copyWith({String? cloudProjectId, String? cloudCapsuleId, String? recordId, DateTime? timestamp, String? severity, String? content}) LogRecord
Returns a shallow copy of this LogRecord with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited