Owner class abstract
- Implemented types
Constructors
-
Owner({UuidValue? id, DateTime? createdAt, DateTime? updatedAt, DateTime? archivedAt, required String externalBillingId, required String externalPaymentId, required Uri billingPortalUrl, required List<
String> billingEmails, User? user, BillingInfo? billingInfo, List<Project> ? projects, DateTime? trialEndingAt, BillingCustomerType? customerType}) -
factory
-
Owner.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- archivedAt ↔ DateTime?
-
If non-null this Owner is archived.
getter/setter pair
-
billingEmails
↔ List<
String> -
getter/setter pair
- billingInfo ↔ BillingInfo?
-
getter/setter pair
- billingPortalUrl ↔ Uri
-
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- customerType ↔ BillingCustomerType?
-
Stop-gap until B2C/B2B migration is supported.
Once non-null this value is mirrored into BillingInfo.customerType when
billing info is set/updated, and may not be changed thereafter.
getter/setter pair
- externalBillingId ↔ String
-
getter/setter pair
- externalPaymentId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ UuidValue
-
The id of the object.
getter/setter pair
-
projects
↔ List<
Project> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trialEndingAt ↔ DateTime?
-
When non-null, the owner's subscription trial ends at this instant (UTC).
getter/setter pair
- updatedAt ↔ DateTime
-
getter/setter pair
- user ↔ User?
-
getter/setter pair
Methods
-
copyWith(
{UuidValue? id, DateTime? createdAt, DateTime? updatedAt, DateTime? archivedAt, String? externalBillingId, String? externalPaymentId, Uri? billingPortalUrl, List< String> ? billingEmails, User? user, BillingInfo? billingInfo, List<Project> ? projects, DateTime? trialEndingAt, BillingCustomerType? customerType}) → Owner - Returns a shallow copy of this Owner with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited