PlanInfo class abstract

Information about a plan product. Contains information to be sent to the client.

Implemented types

Constructors

PlanInfo({required String productId, required String name, required String displayName, String? description, int? trialLength, DateTime? trialEndDate, int? projectsLimit, required List<ProjectProductInfo> projectProductInfo})
factory
PlanInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

description String?
The user-friendly description of the product.
getter/setter pair
displayName String
The user-friendly name of the product. (This is not the same as the technical product ID name.)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
Deprecated: Use displayName instead.
getter/setter pair
productId String
The id of the product.
getter/setter pair
projectProductInfo List<ProjectProductInfo>
The project product definitions bundled with this plan.
getter/setter pair
projectsLimit int?
The limit on the number of projects the subscriber may own, if any.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trialEndDate DateTime?
Trial period fixed end date, if defined. If there is a trial period, either trialLength or trialEndDate is set.
getter/setter pair
trialLength int?
Trial period length in days, if defined. If there is a trial period, either trialLength or trialEndDate is set.
getter/setter pair

Methods

copyWith({String? productId, String? name, String? displayName, String? description, int? trialLength, DateTime? trialEndDate, int? projectsLimit, List<ProjectProductInfo>? projectProductInfo}) PlanInfo
Returns a shallow copy of this PlanInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited