ProcurementCancellationException class abstract

Exception thrown when the cancellation of a procured product failed.

This is distinct from access authorization, and from quota limits.

Implemented types

Constructors

ProcurementCancellationException({required String message, required ProductType productType, required String productId})
factory
ProcurementCancellationException.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The reason the cancellation failed.
getter/setter pair
productId String
The id of the product that was being cancelled.
getter/setter pair
productType ProductType
The type of the product that was being cancelled.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? message, ProductType? productType, String? productId}) ProcurementCancellationException
Returns a shallow copy of this ProcurementCancellationException with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited