copyWith abstract method
Returns a shallow copy of this ProcurementDeniedException with some or all fields replaced by the given arguments.
Implementation
@_i1.useResult
ProcurementDeniedException copyWith({String? message});
Returns a shallow copy of this ProcurementDeniedException with some or all fields replaced by the given arguments.
@_i1.useResult
ProcurementDeniedException copyWith({String? message});