Methods
-
copyWith({String? projectId})
→ ProjectConfig
-
Returns a shallow copy of this ProjectConfig
with some or all fields replaced by the given arguments.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString()
→ String
-
A string representation of this object.
override