ProjectInfo class abstract

Augments a project object with ancillary information.

Ancillary information fields are included according to use case, in which case they are non-null. In other words, null ancillary fields correspond to undefined.

Implemented types

Constructors

ProjectInfo({required Project project, Timestamp? latestDeployAttemptTime})
factory
ProjectInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
latestDeployAttemptTime Timestamp?
The timestamp of the latest deploy attempt, or null if never deployed. (When deploy status is overhauled, this will likely be replaced by a DeployAttempt object.)
getter/setter pair
project Project
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Project? project, Timestamp? latestDeployAttemptTime}) ProjectInfo
Returns a shallow copy of this ProjectInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited