ProjectProductInfo class abstract
Definition of a project product including its compute and database sub-products.
- Implemented types
Constructors
- ProjectProductInfo({required String productId, required String name, required String description, required ComputeCatalogInfo computeCatalog, required DatabaseCatalogInfo databaseCatalog})
-
factory
-
ProjectProductInfo.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- computeCatalog ↔ ComputeCatalogInfo
-
The compute products available under this project product.
getter/setter pair
- databaseCatalog ↔ DatabaseCatalogInfo
-
The database products available under this project product.
getter/setter pair
- description ↔ String
-
The user-friendly description of the product.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
The user-friendly name of the product.
getter/setter pair
- productId ↔ String
-
The id of the product.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? productId, String? name, String? description, ComputeCatalogInfo? computeCatalog, DatabaseCatalogInfo? databaseCatalog}) → ProjectProductInfo - Returns a shallow copy of this ProjectProductInfo with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited