RequiredTerms class abstract

Implemented types

Constructors

RequiredTerms({required Terms termsType, required String termsVersion, required String termsUrl})
factory
RequiredTerms.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsType Terms
getter/setter pair
termsUrl String
getter/setter pair
termsVersion String
getter/setter pair

Methods

copyWith({Terms? termsType, String? termsVersion, String? termsUrl}) RequiredTerms
Returns a shallow copy of this RequiredTerms with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited