The SerializableModel is the base interface for all serializable objects in Serverpod, except primitives.
- Implementers
- AcceptedTerms
- AcceptedTermsDTO
- AuthTokenInfo
- BackupSchedule
- BillingInfo
- BucketFile
- BucketFileListing
- BucketResource
- BucketServiceAccount
- BucketStorageIdentityUnavailableException
- Capsule
- CapsuleDeploymentStatus
- CapsuleNetworkSeries
- CapsuleResource
- CapsuleRevision
- CapsuleRuntimeStatus
- CapsuleStatus
- CapsuleStatusUnavailableException
- ComputeCatalogInfo
- ComputeInfo
- ComputeProductInfo
- ComputeScalingInfo
- ConcurrentSubscriptionUpdateException
- CustomDomainName
- CustomDomainNameList
- CustomDomainNameWithDefaultDomains
- DartSdkUnsupportedConstraintException
- DatabaseCatalogInfo
- DatabaseConnection
- DatabaseInfo
- DatabaseMetrics
- DatabaseProductInfo
- DatabaseQuota
- DatabaseResource
- DatabaseScaling
- DatabaseScalingInfo
- DatabaseSnapshot
- DatabaseSnapshotLimitException
- DatabaseUser
- DeployAttempt
- DeployAttemptStage
- DeployAttemptSummary
- DNSVerificationFailedException
- DuplicateEntryException
- EmailMethodBlockedException
- EnvironmentVariable
- InsightsConnectionDetail
- InvalidValueException
- LogRecord
- MetricSample
- NoCustomerBillingTypeException
- NoPriorDeploymentException
- NoSubscriptionException
- NotFoundException
- Owner
- PaymentMethod
- PaymentMethodCard
- PaymentSetupIntent
- PlanChangeDeniedException
- PlanInfo
- PodResourceSeries
- ProcurementCancellationException
- ProcurementDeniedException
- Project
- ProjectConfig
- ProjectInfo
- ProjectProductInfo
- ProjectProfileUpdate
- PubsubEntry
- RequiredTerms
- ResponseClassSeries
- Role
- SecretResource
- StoredSecretVersion
- SubscriptionInfo
- Timestamp
- UnauthenticatedException
- UnauthorizedException
- User
- UserAccountRegistrationDeniedException
- UserLabelMapping
- UserRoleMembership
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited