SubscriptionInfo class abstract

Information about a subscription. Contains information to be sent to the client.

Implemented types

Constructors

SubscriptionInfo({required DateTime createdAt, required DateTime startDate, DateTime? trialEndDate, DateTime? endDate, required bool cancelled, required UuidValue subscriptionId, required String planProductId, required PlanType planType, String? planName, required String planDisplayName, String? planDescription, int? projectsLimit})
factory
SubscriptionInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

cancelled bool
Whether this subscription has been cancelled.
getter/setter pair
createdAt DateTime
The date the subscription was created.
getter/setter pair
endDate DateTime?
The date the subscription ended / will end, if cancelled or otherwise terminated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
planDescription String?
The plan's description, if any.
getter/setter pair
planDisplayName String
The display name of the plan.
getter/setter pair
planName String?
Deprecated: Use planDisplayName instead.
getter/setter pair
planProductId String
The id of the plan's product.
getter/setter pair
planType PlanType
The public plan type (PlanType.starter / PlanType.growth) when this subscription's plan product maps to one. PlanType.unknown for internal plans (e.g. early-access, hackathon, closed-beta) that aren't user-selectable.
getter/setter pair
projectsLimit int?
The limit on the number of projects the subscriber may own, if any.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
The date the subscription starts billing.
getter/setter pair
subscriptionId UuidValue
The id of the subscription.
getter/setter pair
trialEndDate DateTime?
Trial end date, if currently ongoing.
getter/setter pair

Methods

copyWith({DateTime? createdAt, DateTime? startDate, DateTime? trialEndDate, DateTime? endDate, bool? cancelled, UuidValue? subscriptionId, String? planProductId, PlanType? planType, String? planName, String? planDisplayName, String? planDescription, int? projectsLimit}) SubscriptionInfo
Returns a shallow copy of this SubscriptionInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited