CapsuleBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Capsule -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withCloudCapsuleId(
String cloudCapsuleId) → CapsuleBuilder -
withDomainNames(
List< CustomDomainName> ? domainNames) → CapsuleBuilder -
withEnvironmentVariables(
List< EnvironmentVariable> ? environmentVariables) → CapsuleBuilder -
withId(
int? id) → CapsuleBuilder -
withName(
String name) → CapsuleBuilder -
withProject(
Project? project) → CapsuleBuilder -
withProjectId(
int projectId) → CapsuleBuilder -
withRegion(
ServerpodRegion region) → CapsuleBuilder -
withResourceConfig(
CapsuleResource? resourceConfig) → CapsuleBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited