DatabaseInfoBuilder class

Constructors

DatabaseInfoBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() DatabaseInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withCloudCapsuleId(String cloudCapsuleId) DatabaseInfoBuilder
withComputeHoursLimit(int? computeHoursLimit) DatabaseInfoBuilder
withMaxCu(double? maxCu) DatabaseInfoBuilder
withMemoryMb(int memoryMb) DatabaseInfoBuilder
withMinCu(double? minCu) DatabaseInfoBuilder
withSize(DatabaseSizeOption size) DatabaseInfoBuilder
withStorageLimitGB(int? storageLimitGB) DatabaseInfoBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited