DeployAttemptBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → DeployAttempt -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withAttemptId(
UuidValue attemptId) → DeployAttemptBuilder -
withBranch(
String? branch) → DeployAttemptBuilder -
withCloudCapsuleId(
String cloudCapsuleId) → DeployAttemptBuilder -
withCommitHash(
String? commitHash) → DeployAttemptBuilder -
withCommitMessage(
String? commitMessage) → DeployAttemptBuilder -
withDartVersion(
String? dartVersion) → DeployAttemptBuilder -
withDeployedBy(
User? deployedBy) → DeployAttemptBuilder -
withEndedAt(
DateTime? endedAt) → DeployAttemptBuilder -
withFailedDeployment(
) → DeployAttemptBuilder -
withServerpodVersion(
String? serverpodVersion) → DeployAttemptBuilder -
withStages(
List< DeployAttemptStage> stages) → DeployAttemptBuilder -
withStartedAt(
DateTime? startedAt) → DeployAttemptBuilder -
withStatus(
DeployProgressStatus status) → DeployAttemptBuilder -
withStatusInfo(
String? statusInfo) → DeployAttemptBuilder -
withSuccessfulDeployment(
) → DeployAttemptBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited