EndpointAuthMock class
Methods
-
finishEmailAccountRegistration({required String finishRegistrationToken, required String password})
→ Future<AuthSuccess>
-
Completes a new account registration, creating a new auth user with a
profile, and creating a new authenticated session for the user.
inherited
-
finishPasswordReset({required UuidValue passwordResetRequestId, required String verificationCode, required String newPassword})
→ Future<AuthSuccess>
-
Completes a password reset request by setting a new password.
inherited
-
login({required String email, required String password})
→ Future<AuthSuccess>
-
Logs in the user and returns a new session.
inherited
-
logoutDevice()
→ Future<void>
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
readRequiredTerms()
→ Future<List<RequiredTerms>>
-
inherited
-
resetStream()
→ void
-
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(SerializableModel message)
→ Future<void>
-
Sends a message to the endpoint's stream.
inherited
-
startEmailAccountRegistration({required String email, String? name, required List<AcceptedTermsDTO> acceptedTerms})
→ Future<void>
-
Starts the registration for a new user account with an email-based login.
inherited
-
startPasswordReset({required String email})
→ Future<void>
-
Requests a password reset for
email.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
verifyRegistrationCode({required UuidValue accountRequestId, required String verificationCode})
→ Future<String>
-
Verifies a registration code and returns the finish registration token.
inherited