EndpointAuthWithAuthMock class

Implemented types

Constructors

EndpointAuthWithAuthMock()

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

createCliToken({DateTime? expiresAt, Duration? expiresAfter}) Future<AuthSuccess>
Creates a new authenticated session for the current user to use as CLI token / personal access token.
inherited
listAuthSessions() Future<List<AuthTokenInfo>>
inherited
logoutAll() Future<void>
Log out the current user from all sessions including API tokens.
inherited
logoutDevice({String? authTokenId}) Future<bool>
Log out the current user from a login session. If no authTokenId is provided, it will log out the current one. The user's other login sessions and API tokens will not be affected.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited