EndpointSecretsMock class

Implemented types

Constructors

EndpointSecretsMock()

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

create({required Map<String, String> secrets, required String cloudCapsuleId}) Future<void>
Creates custom (user-defined) secrets for a cloud capsule.
inherited
delete({required String key, required String cloudCapsuleId}) Future<void>
Deletes a custom (user-defined) secret from a cloud capsule.
inherited
deleteBuild({required String cloudCapsuleId, required String key}) Future<void>
Deletes a build secret from a cloud capsule.
inherited
list(String cloudCapsuleId) Future<List<String>>
Lists custom (user-defined) secret keys for a cloud capsule.
inherited
listBuild(String cloudCapsuleId) Future<List<String>>
Lists build secrets keys for a cloud capsule.
inherited
listManaged(String cloudCapsuleId) Future<List<String>>
Lists platform-managed secret keys for a cloud capsule.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
toString() String
A string representation of this object.
inherited
upsert({required Map<String, String> secrets, required String cloudCapsuleId}) Future<void>
Upserts custom (user-defined) secrets for a cloud capsule.
inherited
upsertBuildSecret({required String secretKey, required String secretValue, required BuildSecretType buildSecretType, required String cloudCapsuleId}) Future<void>
Upserts a build secret for a cloud capsule. Build secrets are used during the build process. They are not accessible at runtime.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited