LogRecordBuilder class

Constructors

LogRecordBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() LogRecord
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withCloudCapsuleId(String cloudCapsuleId) LogRecordBuilder
withCloudIds(String cloudId) LogRecordBuilder
Sets the cloud project and capsule IDs to the same value.
withCloudProjectId(String cloudProjectId) LogRecordBuilder
withContent(String content) LogRecordBuilder
withDeployAttemptId(UuidValue deployAttemptId) LogRecordBuilder
withRecordId(String recordId) LogRecordBuilder
withServerInstanceId(String? serverInstanceId) LogRecordBuilder
withSeverity(String? severity) LogRecordBuilder
withTimestamp(DateTime timestamp) LogRecordBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited