PlanInfoBuilder class

Constructors

PlanInfoBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() PlanInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withDescription(String? description) PlanInfoBuilder
withDisplayName(String displayName) PlanInfoBuilder
withDynamicTrailOf30Days() PlanInfoBuilder
withHackathon2025() PlanInfoBuilder
withProductId(String productId) PlanInfoBuilder
withProjectProductInfo(List<ProjectProductInfo> info) PlanInfoBuilder
withProjectsLimit(int? projectsLimit) PlanInfoBuilder
withStaticTrailOf30Days() PlanInfoBuilder
withTrialEndDate(DateTime? trialEndDate) PlanInfoBuilder
withTrialLength(int? trialLength) PlanInfoBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited