Constructors
-
BillingInfo({UuidValue? id, DateTime? createdAt, DateTime? updatedAt, required UuidValue ownerId, Owner? owner, String? companyName, required String addressLine1, String? addressLine2, required String postalCode, required String city, String? state, required String country, String? vatNumber, String? vatType, BillingCustomerType? customerType})
-
factory
-
BillingInfo.fromJson(Map<String, dynamic> jsonSerialization)
-
factory
Methods
-
copyWith({UuidValue? id, DateTime? createdAt, DateTime? updatedAt, UuidValue? ownerId, Owner? owner, String? companyName, String? addressLine1, String? addressLine2, String? postalCode, String? city, String? state, String? country, String? vatNumber, String? vatType, BillingCustomerType? customerType})
→ BillingInfo
-
Returns a shallow copy of this BillingInfo
with some or all fields replaced by the given arguments.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString()
→ String
-
A string representation of this object.
override