Capsule class abstract
Represents an infrastructure capsule instance (a deployment target).
- Implemented types
Constructors
-
Capsule({int? id, required String name, required String cloudCapsuleId, required ServerpodRegion region, required int projectId, Project? project, List<
EnvironmentVariable> ? environmentVariables, List<CustomDomainName> ? domainNames, CapsuleResource? resourceConfig}) -
factory
-
Capsule.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- cloudCapsuleId ↔ String
-
Globally unique identifier of the capsule. Cannot be changed.
getter/setter pair
-
domainNames
↔ List<
CustomDomainName> ? -
The domain names for this capsule.
getter/setter pair
-
environmentVariables
↔ List<
EnvironmentVariable> ? -
Environment variables for this capsule.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- name ↔ String
-
The name of the capsule. User-defined.
getter/setter pair
- project ↔ Project?
-
The project this capsule belongs to. Cannot be changed.
getter/setter pair
- projectId ↔ int
-
getter/setter pair
- region ↔ ServerpodRegion
-
The region where the capsule is hosted. Cannot be changed.
getter/setter pair
- resourceConfig ↔ CapsuleResource?
-
The resource config for the capsule.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, String? name, String? cloudCapsuleId, ServerpodRegion? region, int? projectId, Project? project, List< EnvironmentVariable> ? environmentVariables, List<CustomDomainName> ? domainNames, CapsuleResource? resourceConfig}) → Capsule - Returns a shallow copy of this Capsule with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited