CapsuleResource class abstract
- Implemented types
Constructors
- CapsuleResource({int? id, required int cloudCapsuleId, Capsule? capsule, String? computeRequestCpu, String? computeRequestMemory, String? computeRequestEphemeralStorage, String? computeLimitCpu, String? computeLimitMemory, String? computeLimitEphemeralStorage, bool? computeScalingEnabled, int? computeScalingMinReplicas, int? computeScalingMaxReplicas})
-
factory
-
CapsuleResource.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- capsule ↔ Capsule?
-
The capsule this resource config belongs to.
getter/setter pair
- cloudCapsuleId ↔ int
-
The foreign key to the capsule.
getter/setter pair
- computeLimitCpu ↔ String
-
The compute limit cpu.
getter/setter pair
- computeLimitEphemeralStorage ↔ String
-
The compute limit ephemeral storage.
getter/setter pair
- computeLimitMemory ↔ String
-
The compute limit memory.
getter/setter pair
- computeRequestCpu ↔ String
-
The compute request cpu.
getter/setter pair
- computeRequestEphemeralStorage ↔ String
-
The compute request ephemeral storage.
getter/setter pair
- computeRequestMemory ↔ String
-
The compute request memory.
getter/setter pair
- computeScalingEnabled ↔ bool
-
Flag to enable horizontal scaling for the capsule compute.
getter/setter pair
- computeScalingMaxReplicas ↔ int
-
The maximum number of compute instances to scale to.
getter/setter pair
- computeScalingMinReplicas ↔ int
-
The minimum number of compute instances to scale to.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, int? cloudCapsuleId, Capsule? capsule, String? computeRequestCpu, String? computeRequestMemory, String? computeRequestEphemeralStorage, String? computeLimitCpu, String? computeLimitMemory, String? computeLimitEphemeralStorage, bool? computeScalingEnabled, int? computeScalingMinReplicas, int? computeScalingMaxReplicas}) → CapsuleResource - Returns a shallow copy of this CapsuleResource with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited