DatabaseConnection class abstract
- Implemented types
Constructors
- DatabaseConnection({required String host, required int port, required String name, required String user, bool? requiresSsl})
-
factory
-
DatabaseConnection.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- port ↔ int
-
getter/setter pair
- requiresSsl ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user ↔ String
-
getter/setter pair
Methods
-
copyWith(
{String? host, int? port, String? name, String? user, bool? requiresSsl}) → DatabaseConnection - Returns a shallow copy of this DatabaseConnection with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited