DeployAttempt class abstract
Represents the status information of a deployment attempt.
- Implemented types
Constructors
- DeployAttempt({required String cloudCapsuleId, required String attemptId, required DeployProgressStatus status, DateTime? startedAt, DateTime? endedAt, String? statusInfo})
-
factory
-
DeployAttempt.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- attemptId ↔ String
-
The ID of this deploy attempt.
getter/setter pair
- cloudCapsuleId ↔ String
-
The ID of the capsule of this deployment.
getter/setter pair
- endedAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt ↔ DateTime?
-
getter/setter pair
- status ↔ DeployProgressStatus
-
The current status of this deployment.
getter/setter pair
- statusInfo ↔ String?
-
Optionally contains user-readable information about the current status of this attempt.
getter/setter pair
Methods
-
copyWith(
{String? cloudCapsuleId, String? attemptId, DeployProgressStatus? status, DateTime? startedAt, DateTime? endedAt, String? statusInfo}) → DeployAttempt - Returns a shallow copy of this DeployAttempt with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited