ownerIsInGoodStanding method
Checks if the owner is in good standing.
Verifies that the owner's billing account is active and has no outstanding issues that would prevent normal operation of the service.
Implementation
_i2.Future<bool> ownerIsInGoodStanding() =>
caller.callServerEndpoint<bool>('billing', 'ownerIsInGoodStanding', {});