EndpointBucketObjects class Endpoint
Endpoint for the object contents of a capsule's storage buckets.
- Inheritance
-
- Object
- EndpointRef
- EndpointBucketObjects
Constructors
- EndpointBucketObjects(EndpointCaller caller)
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createUploadDescription(
{required String cloudCapsuleId, required String storageId, required String path}) → Future< String> -
Builds a signed direct-upload description (JSON) for
pathin a capsule's bucket. -
deleteFile(
{required String cloudCapsuleId, required String storageId, required String path}) → Future< void> -
Deletes the file at
pathfrom a capsule's bucket. -
getDownloadUrl(
{required String cloudCapsuleId, required String storageId, required String path}) → Future< String> -
Builds a signed download URL for
pathin a capsule's bucket. -
listFiles(
{required String cloudCapsuleId, required String storageId, String? prefix, String? pageToken}) → Future< BucketFileListing> -
Lists a page of files in a capsule's bucket, optionally filtered by
prefixand continued frompageToken. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited