verifyRegistrationCode method
Verifies an account request code and returns a token that can be used to complete the account creation.
Throws an EmailAccountRequestException in case of errors, with reason:
EmailAccountRequestExceptionReason.expiredif the account request has already expired.EmailAccountRequestExceptionReason.policyViolationif the password does not comply with the password policy.EmailAccountRequestExceptionReason.invalidif no request exists for the givenaccountRequestIdorverificationCodeis invalid.
Implementation
@override
_i2.Future<String> verifyRegistrationCode({
required _i1.UuidValue accountRequestId,
required String verificationCode,
}) =>
caller.callServerEndpoint<String>('emailIdp', 'verifyRegistrationCode', {
'accountRequestId': accountRequestId,
'verificationCode': verificationCode,
});