procurePlan method
Future<UuidValue>
procurePlan({
- String? planProductName,
- @Deprecated('Use planProductName instead') String? planName,
Procures a subscription plan.
Returns the ID of the created subscription.
For plans that depend on the customer billing type (private / business), BillingCustomerType.private is used when no customer billing type is set.
If the plan is not available to procure, a ProcurementDeniedException is thrown.
Implementation
_i2.Future<_i1.UuidValue> procurePlan({
String? planProductName,
@Deprecated('Use planProductName instead') String? planName,
}) => caller.callServerEndpoint<_i1.UuidValue>('plans', 'procurePlan', {
'planProductName': planProductName,
'planName': planName,
});