getCapsuleStatus method
Gets the live runtime status of the specified capsule. An unhealthy capsule is still a successful result — the status is data.
Implementation
_i2.Future<_i40.CapsuleStatus> getCapsuleStatus({
required String cloudCapsuleId,
}) => caller.callServerEndpoint<_i40.CapsuleStatus>(
'status',
'getCapsuleStatus',
{'cloudCapsuleId': cloudCapsuleId},
);