Owner class abstract

Implemented types

Constructors

Owner({UuidValue? id, required String externalBillingId, required String externalPaymentId, required Uri billingPortalUrl, required List<String> billingEmails, String? primarySubscriptionId, User? user, BillingInfo? billingInfo, List<Project>? projects})
factory
Owner.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

billingEmails List<String>
getter/setter pair
billingInfo BillingInfo?
getter/setter pair
billingPortalUrl Uri
getter/setter pair
externalBillingId String
getter/setter pair
externalPaymentId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id UuidValue
The id of the object.
getter/setter pair
primarySubscriptionId String?
The id of the primary (default) subscription of this owner. Null if the owner has no subscription.
getter/setter pair
projects List<Project>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User?
getter/setter pair

Methods

copyWith({UuidValue? id, String? externalBillingId, String? externalPaymentId, Uri? billingPortalUrl, List<String>? billingEmails, String? primarySubscriptionId, User? user, BillingInfo? billingInfo, List<Project>? projects}) Owner
Returns a shallow copy of this Owner with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited