AuthTokenInfoBuilder class
Constructors
Properties
- expireAfterUnusedFor ↔ Duration?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUsedAt ↔ DateTime?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → AuthTokenInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withCreatedAt(
DateTime createdAt) → AuthTokenInfoBuilder -
withExpireAfterUnusedFor(
Duration? expireAfterUnusedFor) → AuthTokenInfoBuilder -
withExpiresAt(
DateTime? expiresAt) → AuthTokenInfoBuilder -
withIssuer(
String issuer) → AuthTokenInfoBuilder -
withLastUsedAt(
DateTime? lastUsedAt) → AuthTokenInfoBuilder -
withMethod(
String method) → AuthTokenInfoBuilder -
withTokenId(
String tokenId) → AuthTokenInfoBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited