ComputeInfoBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → ComputeInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withCloudCapsuleId(
String cloudCapsuleId) → ComputeInfoBuilder -
withMaxInstances(
int maxInstances) → ComputeInfoBuilder -
withMemoryMb(
int memoryMb) → ComputeInfoBuilder -
withMinInstances(
int minInstances) → ComputeInfoBuilder -
withSize(
ComputeSizeOption size) → ComputeInfoBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited