DartSdkVersionPolicyBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → DartSdkVersionPolicy -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withDefaultVersion(
String defaultVersion) → DartSdkVersionPolicyBuilder -
withDocumentationUrl(
Uri documentationUrl) → DartSdkVersionPolicyBuilder -
withMaxVersionExclusive(
String maxVersionExclusive) → DartSdkVersionPolicyBuilder -
withMinVersionInclusive(
String minVersionInclusive) → DartSdkVersionPolicyBuilder -
withSupportedVersions(
List< String> supportedVersions) → DartSdkVersionPolicyBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited