DeployAttemptBuilder class

Constructors

DeployAttemptBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() DeployAttempt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withAttemptId(String attemptId) DeployAttemptBuilder
withCloudCapsuleId(String cloudCapsuleId) DeployAttemptBuilder
withEndedAt(DateTime? endedAt) DeployAttemptBuilder
withStartedAt(DateTime? startedAt) DeployAttemptBuilder
withStatus(DeployProgressStatus status) DeployAttemptBuilder
withStatusInfo(String? statusInfo) DeployAttemptBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited