EndpointDatabaseMock class
Methods
-
createSnapshot({required String cloudCapsuleId, String? name, DateTime? expiresAt})
→ Future<DatabaseSnapshot>
-
Creates a manual snapshot of the capsule's database.
inherited
-
createSuperUser({required String cloudCapsuleId, required String username})
→ Future<String>
-
Creates a new super user in the database.
Returns the password for the new user.
inherited
-
deleteSnapshot({required String cloudCapsuleId, required String snapshotId})
→ Future<void>
-
Deletes a snapshot of the capsule's database.
inherited
-
enableDatabase({required String cloudCapsuleId})
→ Future<void>
-
Enables the database for a project.
inherited
-
getBackupSchedule({required String cloudCapsuleId})
→ Future<BackupSchedule?>
-
Returns the automated backup schedule for the capsule's database, or null
if none is configured.
inherited
-
getConnectionDetails({required String cloudCapsuleId})
→ Future<DatabaseConnection>
-
Returns the connection details for a database resource.
Throws NotFoundException if the database is not found.
inherited
-
listSnapshots({required String cloudCapsuleId})
→ Future<List<DatabaseSnapshot>>
-
Lists the snapshots of the capsule's database.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
readDatabase({required String cloudCapsuleId})
→ Future<DatabaseInfo>
-
Returns persisted database capacity and quota for
cloudCapsuleId.
inherited
-
resetDatabasePassword({required String cloudCapsuleId, required String username})
→ Future<String>
-
Resets the password for a user in the database.
Returns the new password for the user.
inherited
-
resetStream()
→ void
-
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
restoreFromSnapshot({required String cloudCapsuleId, required String snapshotId})
→ Future<void>
-
Restores the capsule's live database to the given snapshot.
inherited
-
sendStreamMessage(SerializableModel message)
→ Future<void>
-
Sends a message to the endpoint's stream.
inherited
-
setBackupSchedule({required String cloudCapsuleId, BackupFrequency? frequency, int? day, int? hour, Duration? retention})
→ Future<void>
-
Sets the automated backup schedule for the capsule's database.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateDatabaseSize({required String cloudCapsuleId, required DatabaseSizeOption size, double? minCu, double? maxCu})
→ Future<DatabaseResource>
-
Updates the size and the autoscaling CU limits for a capsule's database,
changing the procured database product if necessary.
The size and limits are validated against the constraints of the capsule's
product.
inherited
-
wipeDatabase({required String cloudCapsuleId})
→ Future<void>
-
Wipes the database by deleting and recreating it.
This will drop all tables and data in the database.
The deployment will error until a redeploy is performed.
inherited